==> nextcloud-16.0.5.tgz: nextcloud/apps/comments/l10n/lt_LT.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarai",
    "You commented" : "Jūs pakomentavote",
    "%1$s commented" : "%1$s pakomentavo",
    "{author} commented" : "{author} pakomentavo",
    "You commented on %1$s" : "Pakomentavote %1$s",
    "You commented on {file}" : "Pakomentavote {file}",
    "%1$s commented on %2$s" : "%1$s pakomentavo %2$s",
    "{author} commented on {file}" : "{author} pakomentavo {file}",
    "<strong>Comments</strong> for files" : "<strong>Failų komentarai</strong>",
    "{user} mentioned you in a comment on “{file}”" : "{user} jus paminėjo komentare “{file}”",
    "Files app plugin to add comments to files" : "Failų programėlės įskiepis, skirtas prie failų pridėti komentarus",
    "Edit comment" : "Taisyti komentarą",
    "Delete comment" : "Ištrinti komentarą",
    "New comment …" : "Naujas komentaras …",
    "Post" : "Įrašas",
    "Cancel" : "Atsisakyti",
    "[Deleted user]" : "[Ištrintas naudotojas]",
    "No comments yet, start the conversation!" : "Nėra komentarų",
    "More comments …" : "Daugiau",
    "Save" : "Įrašyti",
    "Allowed characters {count} of {max}" : "Leidžiama simbolių {count} iš {max}",
    "Error occurred while retrieving comment with ID {id}" : "Klaida gaunant komentarą, kurio ID {id}",
    "Error occurred while updating comment with id {id}" : "Klaida bandant pataisyti komentarą pagal identifikavimo numerį {id}",
    "Error occurred while posting comment" : "Skelbiant komentarą, įvyko klaida",
    "_%n unread comment_::_%n unread comments_" : ["%n neskaitytas komentaras","%n neskaityti komentarai","%n neskaitytų komentarų","%n neskaitytas komentaras"],
    "_1 new comment_::_{unread} new comments_" : ["1 neskaitytas komentaras","{unread} neskaityti komentarai","{unread} neskaitytų komentarų","{unread} neskaitytas komentaras"],
    "Comment" : "Komentaras"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-19.0.3.tgz: nextcloud/apps/comments/l10n/lt_LT.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarai",
    "You commented" : "Jūs pakomentavote",
    "%1$s commented" : "%1$s pakomentavo",
    "{author} commented" : "{author} pakomentavo",
    "You commented on %1$s" : "Pakomentavote %1$s",
    "You commented on {file}" : "Pakomentavote {file}",
    "%1$s commented on %2$s" : "%1$s pakomentavo %2$s",
    "{author} commented on {file}" : "{author} pakomentavo {file}",
    "<strong>Comments</strong> for files" : "Failų <strong>komentarai</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Jus “{file}” komentare paminėjo naudotojas, kuris nuo to laiko buvo ištrintas",
    "{user} mentioned you in a comment on “{file}”" : "{user} paminėjo jus komentare “{file}”",
    "Files app plugin to add comments to files" : "Failų programėlės įskiepis, skirtas prie failų pridėti komentarus",
    "Edit comment" : "Taisyti komentarą",
    "Delete comment" : "Ištrinti komentarą",
    "New comment …" : "Naujas komentaras …",
    "Post" : "Paskelbti",
    "Cancel" : "Atsisakyti",
    "[Deleted user]" : "[Ištrintas naudotojas]",
    "No comments yet, start the conversation!" : "Komentarų nėra, pradėkite pokalbį!",
    "More comments …" : "Daugiau komentarų…",
    "Save" : "Įrašyti",
    "Allowed characters {count} of {max}" : "Leidžiami simboliai {count} iš {max}",
    "Error occurred while retrieving comment with ID {id}" : "Klaida gaunant komentarą, kurio ID {id}",
    "Error occurred while updating comment with id {id}" : "Klaida atnaujinant komentarą, kurio id {id}",
    "Error occurred while posting comment" : "Skelbiant komentarą, įvyko klaida",
    "_%n unread comment_::_%n unread comments_" : ["%n neskaitytas komentaras","%n neskaityti komentarai","%n neskaitytų komentarų","%n neskaitytas komentaras"],
    "_1 new comment_::_{unread} new comments_" : ["1 neskaitytas komentaras","{unread} neskaityti komentarai","{unread} neskaitytų komentarų","{unread} neskaitytas komentaras"],
    "Comment" : "Komentaras"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
